@@ -12,9 +12,10 @@ class DateTimeEncoder(JSONEncoder):
             return obj.isoformat()
 
 
-def ec2_describe_availability_zone(region):
+def ec2_describe_availability_zone(region,AWS_ACCESS_KEY,AWS_SECRET_KEY):
 
-    client = boto3.client('ec2', region_name=region)
+    client = boto3.client('ec2', region_name=region,
+    aws_access_key_id=AWS_ACCESS_KEY,aws_secret_access_key=AWS_SECRET_KEY)
     response = client.describe_availability_zones()
     json_list = json.dumps(response, indent=4, cls=DateTimeEncoder)
     script_dir = os.path.dirname('.')
