@@ -9,8 +9,9 @@ def defaultconverter(o):
         return o.__str__()
 
 
-def ec2_describe_vpc_endpoint(region):
-    client = boto3.client('ec2', region_name=region)
+def ec2_describe_vpc_endpoint(region,AWS_ACCESS_KEY,AWS_SECRET_KEY):
+    client = boto3.client('ec2', region_name=region,
+    aws_access_key_id=AWS_ACCESS_KEY,aws_secret_access_key=AWS_SECRET_KEY)
     response = client.describe_vpc_endpoints()
 
     json_list = json.dumps(response, default=defaultconverter)
