@@ -10,10 +10,10 @@ class DateTimeEncoder(JSONEncoder):
         if isinstance(obj, (datetime.date, datetime.datetime)):
             return obj.isoformat()
 
-def rds_describe_instance(region):
-    client = boto3.client('rds', region_name=region)
+def rds_describe_instance(region,AWS_ACCESS_KEY,AWS_SECRET_KEY):
+    client = boto3.client('rds', region_name=region,
+    aws_access_key_id=AWS_ACCESS_KEY, aws_secret_access_key=AWS_SECRET_KEY)
     response = client.describe_db_instances()
-    print(response)
     json_list = json.dumps(response, indent=4,
     cls=DateTimeEncoder)
     script_dir = os.path.dirname('.')
@@ -22,4 +22,3 @@ def rds_describe_instance(region):
     with open(file_path, 'w') as outfile:
         outfile.write(json_list)
         outfile.close()
-rds_describe_instance('us-west-2')
\ No newline at end of file
